# Additional resources

## API Documentation

- [*Maison de la Teledetection* STAC API](https://api.stac.teledetection.fr/api.html)
- [*THEIA-MTD* STAC API](https://theia.stac.teledetection.fr/api.html)
- [*Maison de la Teledetection* URL signing API](https://signing.stac.teledetection.fr/docs)

## STAC documentation

- [PySTAC documentation](https://pystac.readthedocs.io/en/stable/api/pystac.html)
- [PySTAC-Client documentation](https://pystac-client.readthedocs.io/en/stable/)
- More information about the [STAC specification](https://stacspec.org/en/about/stac-spec/)
